@@ -55,6 +55,9 @@ namespace Opm
           linsolver_type_(3),
           linsolver_smooth_steps_(1),
           gravity_(0.0)
+#if HAVE_MPI
+         , grid_(MPI_COMM_SELF)
+#endif
     {
     }
 
@@ -252,7 +255,7 @@ namespace Opm
 	    // Run pressure solver.
             bool same_matrix = (bctype_ != Fixed) && (pdd != 0);
 	    flow_solver_.solve(fluid, sat, bcond_, src, residual_tolerance_,
-                               linsolver_verbosity_, 
+                               linsolver_verbosity_,
                                linsolver_type_, same_matrix,
                                linsolver_maxit_, linsolver_prolongate_factor_,
                                linsolver_smooth_steps_);
@@ -296,16 +299,9 @@ namespace Opm
 	double side1_area = 0.0;
 	double side2_area = 0.0;
 
-	int num_faces = 0;
-	int num_bdyfaces = 0;
-	int num_side1 = 0;
-	int num_side2 = 0;
-
 	for (CellIter c = ginterf_.cellbegin(); c != ginterf_.cellend(); ++c) {
 	    for (FaceIter f = c->facebegin(); f != c->faceend(); ++f) {
-		++num_faces;
 		if (f->boundary()) {
-		    ++num_bdyfaces;
 		    int canon_bid = bcond_.getCanonicalBoundaryId(f->boundaryId());
 		    if ((canon_bid - 1)/2 == flow_dir) {
 			double flux = flow_solution.outflux(f);
@@ -313,7 +309,6 @@ namespace Opm
 			double norm_comp = f->normal()[flow_dir];
 			// std::cout << "bid " << f->boundaryId() << "   area " << area << "   n " << norm_comp << std::endl;
 			if (canon_bid - 1 == 2*flow_dir) {
-			    ++num_side1;
 			    if (flow_dir == pdrop_dir && flux > 0.0) {
 #ifdef VERBOSE
 			      std::cerr << "Flow may be in wrong direction at bid: " << f->boundaryId()<<" (canonical: "<<canon_bid
@@ -325,7 +320,6 @@ namespace Opm
 			    side1_area += area;
 			} else {
 			    assert(canon_bid - 1 == 2*flow_dir + 1);
-			    ++num_side2;
 			    if (flow_dir == pdrop_dir && flux < 0.0) {
 #ifdef VERBOSE
 				std::cerr << "Flow may be in wrong direction at bid: " << f->boundaryId()
@@ -336,12 +330,10 @@ namespace Opm
 			    side2_flux += flux*norm_comp;
 			    side2_area += area;
 			}
-		    }		    
+		    }
 		}
 	    }
 	}
-// 	std::cout << "Faces: " << num_faces << "   Boundary faces: " << num_bdyfaces
-// 		  << "   Side 1 faces: " << num_side1 << "   Side 2 faces: " << num_side2 << std::endl;
 	// q is the average velocity.
 	return 0.5*(side1_flux/side1_area + side2_flux/side2_area);
     }
@@ -370,7 +362,7 @@ namespace Opm
 			    side2_pos += area*pos_comp;
 			    side2_area += area;
 			}
-		    }		    
+		    }
 		}
 	    }
 	}
